<?php

/* Inclusion des dépendances de cette classe */
require_once('view/View.php');
require_once('control/Controller.php');
require_once('model/AnimalStorage.php');

/**
 * Le routeur s'occupe d'analyser les requêtes HTTP
 * pour décider quoi faire et quoi afficher.
 * Il se contente de passer la main au contrôleur et
 * à la vue une fois qu'il a déterminé l'action à effectuer.
 *
 * Le routeur est censé être le seul à connaître les URL du site:
 * toute classe ayant besoin d'une URL la lui demandera.
 */
class Router {

	/**
	 * Point d'entrée de l'application.
	 * Gère la requête courante en transférant le contrôle
	 * au contrôleur ou à la vue appropriés.
	 */
	public function main(AnimalStorage $animaldb) {
		$view = new View($this);
		$ctl = new Controller($view, $animaldb);

		/* Récupération de l'identifiant dans l'URL */
		$id = key_exists('id', $_GET) ? $_GET['id'] : null;

		/* On remplit la vue en fonction de l'URL.*/
		if (key_exists('liste', $_GET)) {
			/* L'URL contient le paramètre 'liste':
			 * on affiche la liste de tous les animaux. */
			$ctl->showList();
		} else if ($id !== null) {
			/* L'URL contient un identifiant : on affiche la
			 * page de l'animal correspondant */
			$ctl->showInformation($id);
		} else {
			/* pas d'identifiant donné dans l'URL:
			 * on affiche la page d'accueil */
			$view->makeHomePage();
		}

		/* On affiche la vue ainsi complétée. */
		$view->render();
	}

	/**
	 * Renvoie l'URL de la page de l'animal d'identifiant $id.
	 */
	public function getAnimalURL($id) {
		return 'animaux.php?id='.$id;
	}

}

?>
