<?php

/* Inclusion des dépendances de cette classe */
require_once('view/View.php');
require_once('model/Animal.php');
require_once('model/AnimalStorage.php');

/**
 * Le contrôleur effectue les actions demandées
 * et remplit la vue.
 */
class Controller {

	/** La vue utilisée par ce contrôleur pour afficher du HTML. */
	protected $view;

	/** La base de données (ou autre) contenant les animaux. */
	protected $animaldb;

	/**
	 * Construit un nouveau contrôleur.
	 */
	public function __construct(View $view, AnimalStorage $animaldb) {
		$this->view = $view;
		$this->animaldb = $animaldb;
	}

	/**
	 * Fait le nécessaire pour que la vue puisse
	 * afficher la page d'un animal.
	 */
	public function showInformation($id) {
		$animal = $this->animaldb->read($id);
		if ($animal !== null) {
			$this->view->makeAnimalPage($animal);
		} else {
			$this->view->makeUnknownAnimalPage();
		}
	}

	/**
	 * Fait le nécessaire pour que la vue puisse
	 * afficher la liste de tous les animaux.
	 */
	public function showList() {
		$this->view->makeListPage($this->animaldb->readAll());
	}

}

?>
